=================================================
Cirrocumulus for Single-Cell Data Visualization
=================================================

Cirrocumulus is an interactive visualization tool for large-scale single-cell genomics data, with the following key features:

* Run on Google App Engine or on your local machine
* Scale to > 6 million cells on commodity hardware
* Share datasets with collaborators
* Interactively create and share cell annotations
* Explore multiple features and embeddings simultaneously
* Visualize 2-d and 3-d embeddings
* Save publication quality images